//
//  AddEventController.m
//  CalendarEvents
//
//  Created by kelley.ricker on 4/4/16.
//  Copyright © 2016 GrapeCity. All rights reserved.
//

#import "AddEventController.h"

@interface AddEventController (){
    UILabel *eventLabel;
    UITextField *eventField;
    UILabel *startLabel;
    UITextField *startField;
    UIDatePicker *startPicker;
    UILabel *endLabel;
    UITextField *endField;
    UIDatePicker *endPicker;
    UIButton *commitEventButton;

}

@end

@implementation AddEventController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    [self setTitle:@"Add Event"];
    self.edgesForExtendedLayout = UIRectEdgeNone;
    self.view.backgroundColor = [UIColor whiteColor];
    
    startPicker = [[UIDatePicker alloc] init];
    endPicker = [[UIDatePicker alloc] init];
    [startPicker addTarget:self action:@selector(startPickerChanged:) forControlEvents:UIControlEventValueChanged];
    [endPicker addTarget:self action:@selector(endPickerChanged:) forControlEvents:UIControlEventValueChanged];
    
    startPicker.minuteInterval = 15;
    endPicker.minuteInterval = 15;
    startPicker.date = self.startTime;
    endPicker.date = self.endTime;
    
    NSDateFormatter *dateFormat = [[NSDateFormatter alloc] init];
    [dateFormat setDateFormat:@"LLLL dd h:mm a"];
    
    eventLabel = [[UILabel alloc] init];
    eventLabel.text = @"Event Name: ";
    
    eventField = [[UITextField alloc] init];
    eventField.text = @"New Event";
    eventField.backgroundColor = [UIColor colorWithRed:0.93 green:0.93 blue:0.93 alpha:1.0];
    
    startLabel = [[UILabel alloc] init];
    startLabel.text = @"Start Time: ";
    
    startField = [[UITextField alloc] init];
    startField.text = [dateFormat stringFromDate:self.startTime];
    startField.backgroundColor = [UIColor colorWithRed:0.93 green:0.93 blue:0.93 alpha:1.0];
    
    endLabel = [[UILabel alloc] init];
    endLabel.text = @"End Time: ";
    
    endField = [[UITextField alloc] init];
    endField.text = [dateFormat stringFromDate:self.endTime];
    endField.backgroundColor = [UIColor colorWithRed:0.93 green:0.93 blue:0.93 alpha:1.0];
    
    commitEventButton = [UIButton buttonWithType:UIButtonTypeSystem];
    
    [commitEventButton setTitle:@"Add Event" forState:UIControlStateNormal];
    commitEventButton.tintColor = [UIColor orangeColor];
    [commitEventButton addTarget:self action:@selector(addClicked) forControlEvents:UIControlEventTouchUpInside];
    [[commitEventButton layer] setBorderWidth:1.0f];
    [[commitEventButton layer] setCornerRadius:4.0f];
    commitEventButton.layer.borderColor = [UIColor orangeColor].CGColor;
    
    
    UIToolbar *toolbar = [[UIToolbar alloc] initWithFrame:CGRectMake(0, 0, self.view.frame.size.width, 44)];
    UIBarButtonItem *done = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemDone target:self action:@selector(endEditPicker:)];
    UIBarButtonItem *space = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemFlexibleSpace target:nil action:nil];
    [toolbar setItems:@[space, done]];
    
    endField.inputView = endPicker;
    endField.inputAccessoryView = toolbar;
    
    startField.inputView = startPicker;

    startField.inputAccessoryView = toolbar;
    
    [self.view addSubview:eventLabel];
    [self.view addSubview:eventField];
    [self.view addSubview:startLabel];
    [self.view addSubview:startField];
    [self.view addSubview:endLabel];
    [self.view addSubview:endField];
    [self.view addSubview:commitEventButton];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}
- (void)viewDidLayoutSubviews {
    [super viewDidLayoutSubviews];
    eventLabel.frame = CGRectMake(self.view.bounds.size.width/2 - 150, 5, 300, 30);
    eventField.frame = CGRectMake(self.view.bounds.size.width/2 - 150, 40, 300, 30);
    startLabel.frame = CGRectMake(self.view.bounds.size.width/2 - 150, 75, 300, 30);
    startField.frame = CGRectMake(self.view.bounds.size.width/2 - 150, 105, 300, 30);
    endLabel.frame = CGRectMake(self.view.bounds.size.width/2 - 150, 140, 300, 30);
    endField.frame = CGRectMake(self.view.bounds.size.width/2 - 150, 175, 300, 30);
    commitEventButton.frame = CGRectMake(self.view.bounds.size.width/2 - 150, self.view.bounds.size.height - 60, 300, 40);
}
- (BOOL)endEditPicker:(UITextField *)textField {

    [startField endEditing:true];
    [endField endEditing:true];
    
    return true;
}
-(void)startPickerChanged:(UIPickerView *) picker{
    NSDateFormatter *dateFormat = [[NSDateFormatter alloc] init];
    [dateFormat setDateFormat:@"LLLL dd h:mm a"];
    self.startTime = startPicker.date;
    startField.text = [dateFormat stringFromDate:self.startTime];
}
-(void)endPickerChanged:(UIPickerView *) picker{
    NSDateFormatter *dateFormat = [[NSDateFormatter alloc] init];
    [dateFormat setDateFormat:@"LLLL dd h:mm a"];
    self.endTime = endPicker.date;
    endField.text = [dateFormat stringFromDate:self.endTime];
}

-(void)addClicked{
    EKEvent *event = [EKEvent eventWithEventStore:self.eventStore];
    event.title = eventField.text;
    event.startDate = self.startTime;
    event.endDate = self.endTime;
    [event setCalendar:[self.eventStore defaultCalendarForNewEvents]];
    NSError *err;
    [self.eventStore saveEvent:event span:EKSpanThisEvent commit:true error:&err];
    [self.navigationController popViewControllerAnimated:true];
}

@end
