//
//  ViewController.m
//  CalendarEvents
//
//  Created by kelley.ricker on 3/30/16.
//  Copyright © 2016 GrapeCity. All rights reserved.
//

#import "ViewController.h"
#import "AddEventController.h"

@interface ViewController (){
    XuniCalendar *calendar;
    UITableView *tv;
    
    EKEventStore *eventStore;
    bool isAccessGranted;
    
    NSDate *sdate;
    NSDate *edate;
    
    NSInteger maxDays;
    //NSMutableArray *tvData;
    NSString *selectedDate;
    NSArray *eventsArray;
    
}

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    [self setTitle:@"Calendar Events"];
    self.edgesForExtendedLayout = UIRectEdgeNone;
    calendar = [[XuniCalendar alloc] initWithFrame:CGRectZero];
    maxDays = 365;
    NSTimeInterval maxDaysInSeconds = (60.0 * 60.0 * 24.0 * maxDays);
    
    eventStore = [[EKEventStore alloc] init];
    
    sdate = [NSDate date];
    edate = [NSDate date];
    
    calendar.delegate = self;
    calendar.maxSelectionCount = 1;
    calendar.minDate = [NSDate date];
    calendar.maxDate = [NSDate dateWithTimeIntervalSinceNow:maxDaysInSeconds];
    calendar.adjacentDayTextColor = [UIColor colorWithRed:120/255 green:120/255 blue:120/255 alpha:1];
    calendar.selectionBackgroundColor = [UIColor colorWithRed:0.93 green:0.93 blue:0.93 alpha:1.0];
    tv = [[UITableView alloc] init];
    //tvData = [[NSMutableArray alloc] init];
    selectedDate = [[NSString alloc] init];
    selectedDate = @"";
    tv.delegate = self;
    tv.dataSource = self;
    tv.tintColor = [UIColor whiteColor];
    
    [self updateAuthorizationStatusToAccessEventStore];
    [self.view addSubview:calendar];
    [self.view addSubview:tv];
}

-(void)viewDidAppear:(BOOL)animated{
    [super viewDidAppear:true];
    [calendar refresh];
    dispatch_async(dispatch_get_main_queue(), ^{
        [self fetchEventsWithStart:sdate end:edate];
        [tv reloadData];
    });

}


- (void)updateAuthorizationStatusToAccessEventStore {
    EKAuthorizationStatus authorizationStatus = [EKEventStore authorizationStatusForEntityType:EKEntityTypeEvent];
    switch (authorizationStatus) {

        case EKAuthorizationStatusDenied:
        case EKAuthorizationStatusRestricted: {
            isAccessGranted = NO;
            UIAlertController* alert = [UIAlertController alertControllerWithTitle:@"Access Denied"
                message:@"App needs permission to access calendar events"
                preferredStyle:UIAlertControllerStyleAlert];
            UIAlertAction* defaultAction = [UIAlertAction actionWithTitle:@"Dismiss" style:UIAlertActionStyleDefault handler:^(UIAlertAction * action) {}];
            [alert addAction:defaultAction];
            [self presentViewController:alert animated:YES completion:nil];
            [tv reloadData];
            break;
        }
        case EKAuthorizationStatusAuthorized:
            isAccessGranted = YES;
            [tv reloadData];
            break;
            
        case EKAuthorizationStatusNotDetermined: {
            [eventStore requestAccessToEntityType:EKEntityTypeEvent
                                    completion:^(BOOL granted, NSError *error) {
                                                dispatch_async(dispatch_get_main_queue(), ^{
                                                    isAccessGranted = granted;
                                                    [tv reloadData];
                                                });
                                            }];
            break;
        }
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}
- (void)viewDidLayoutSubviews {
    [super viewDidLayoutSubviews];
    CGSize size = self.view.bounds.size;
    
    calendar.frame = CGRectMake(0, 0, size.width, size.height/2 - 5);
    tv.frame = CGRectMake(0, size.height/2, size.width, size.height/2);
}

- (void)addClicked{
    AddEventController *controller = [[AddEventController alloc] init];
    controller.startTime = sdate;
    controller.endTime = edate;
    controller.eventStore = eventStore;
    [self.navigationController pushViewController:controller animated:true];
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section{
    return 50;
}

- (UIView *)tableView:(UITableView *)tableView viewForHeaderInSection:(NSInteger)section {
    CGRect frame = tableView.frame;
    
    UIButton *addButton = [UIButton buttonWithType:UIButtonTypeSystem];
    addButton.frame = CGRectMake(frame.size.width-60, 10, 50, 30);
    [addButton  setTitle:@"+" forState:UIControlStateNormal];
    addButton.tintColor = [UIColor orangeColor];
    addButton.titleLabel.font = [UIFont systemFontOfSize:24];
    [addButton addTarget:self action:@selector(addClicked) forControlEvents:UIControlEventTouchUpInside];
    
    
    UILabel *title = [[UILabel alloc] initWithFrame:CGRectMake(10, 10, 250, 30)];
    title.text = [[@"Selected Date" stringByAppendingString:@" "]stringByAppendingString: selectedDate];
    
    UIView *headerView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, frame.size.width, frame.size.height)];
    [headerView addSubview:title];
    [headerView addSubview:addButton];
    headerView.backgroundColor = [UIColor colorWithRed:0.93 green:0.93 blue:0.93 alpha:1.0];
    return headerView;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [eventsArray count];
}


- (UITableViewCell *)tableView:(UITableView *)tableview cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    NSString *SimpleIdentifier = @"SimpleIdentifier";
    UITableViewCell *cell = [tableview dequeueReusableCellWithIdentifier:SimpleIdentifier];

    EKEvent *event = [eventsArray objectAtIndex:indexPath.row];

    if (cell == nil){
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:SimpleIdentifier];
    }
    
    cell.textLabel.text = event.title;
    NSDateFormatter *dateFormat = [[NSDateFormatter alloc] init];
    [dateFormat setDateFormat:@"h:mm a"];
    cell.detailTextLabel.text = [[[dateFormat stringFromDate: event.startDate] stringByAppendingString:@" - "]stringByAppendingString:[dateFormat stringFromDate: event.endDate]];
  
    return cell;
}

- (void)fetchEventsWithStart:(NSDate *)start end:(NSDate *) end{
    if (isAccessGranted) {

        NSPredicate *predicate =
        [eventStore predicateForEventsWithStartDate:start endDate:end calendars:nil];
    
        eventsArray = [eventStore eventsMatchingPredicate:predicate];

    }
}

-(void)selectionChanged:(XuniCalendar *)sender args:(XuniCalendarSelectionChangedEventArgs *)args{
    
    NSDateFormatter *dateFormat = [[NSDateFormatter alloc] init];
    [dateFormat setDateFormat:@"LLLL dd yyyy"];
    selectedDate = [dateFormat stringFromDate:args.selectedDates.startDate];
    
    NSCalendar *cal = [NSCalendar currentCalendar];
    NSCalendarUnit preservedComponent = (NSCalendarUnitYear | NSCalendarUnitMonth | NSCalendarUnitDay);
    NSDateComponents *components = [cal components:preservedComponent fromDate:args.selectedDates.startDate];
    NSDateComponents *oneDayPlus = [[NSDateComponents alloc] init];
    oneDayPlus.day = 1;
    sdate = [cal dateFromComponents:components];
    
    components = [cal components:preservedComponent fromDate:args.selectedDates.endDate];
    
    edate = [cal dateByAddingComponents:oneDayPlus toDate:[cal dateFromComponents:components] options:0];

    dispatch_async(dispatch_get_main_queue(), ^{
        [self fetchEventsWithStart:sdate end:edate];
        [tv reloadData];
    });
}

-(void)daySlotLoading:(XuniCalendar *)sender args:(XuniCalendarDaySlotLoadingEventArgs *)args{
    NSDate *start;
    NSDate *end;
    NSCalendar *cal = [NSCalendar currentCalendar];
    NSCalendarUnit preservedComponent = (NSCalendarUnitYear | NSCalendarUnitMonth | NSCalendarUnitDay);
    NSDateComponents *components = [cal components:preservedComponent fromDate:args.date];
    NSDateComponents *oneDayPlus = [[NSDateComponents alloc] init];
    oneDayPlus.day = 1;
    start = [cal dateFromComponents:components];
    
    components = [cal components:preservedComponent fromDate:args.date];
    
    end = [cal dateByAddingComponents:oneDayPlus toDate:[cal dateFromComponents:components] options:0];
    
    [self fetchEventsWithStart:start end:end];
    if(eventsArray){
        CGRect rect = args.daySlot.frame;
        CGSize size = rect.size;
        CGRect rect1, rect2;
        XuniCalendarImageDaySlot *imageDaySlot = [[XuniCalendarImageDaySlot alloc] initWithCalendar:sender frame:rect];
        rect1 = CGRectMake(0, 0, size.width, size.height / 6 * 4);
        rect2 = CGRectMake(size.width / 2 - 4, size.height / 6 * 4, 8, 8);

        imageDaySlot.dayTextRect = rect1;
        imageDaySlot.imageRect = rect2;

        imageDaySlot.imageSource = [UIImage imageNamed:@"event"];

        args.daySlot = imageDaySlot;
        args.daySlot.layer.cornerRadius = 4.0f;
        args.daySlot.clipsToBounds = true;
    }
}
@end
